@@ -1,20 +1,18 @@
-## ----setup, include = FALSE----------------------------------------------
+## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
 
-## ----RasterCode, eval = FALSE--------------------------------------------
+## ----RasterCode, eval = FALSE-------------------------------------------------
 #  library(raster)
 #  set.seed(860)
 #  test.raster <- raster(nrows=100, ncols=100, xmn=-50, xmx=50, ymn=-50,ymx=50)
 #  test.raster[] <- runif(10000, -80, 150)
 #  test.raster <- focal(focal(test.raster, w=matrix(1, 5, 5), mean), w=matrix(1, 5, 5), mean)
 
-## ----RasterCode2, echo = FALSE, message=FALSE----------------------------
+## ----RasterCode2, echo = FALSE, message=FALSE---------------------------------
 library(raster)
-library(ggplot2)
-library(viridis)
 set.seed(860)
 test.raster <- raster(nrows=100, ncols=100, xmn=-50, xmx=50, ymn=-50,ymx=50)
 test.raster[] <- runif(10000, -80, 150)
@@ -22,12 +20,19 @@ test.raster <- focal(focal(test.raster, w=matrix(1, 5, 5), mean), w=matrix(1, 5,
 
 test.raster_df <- as.data.frame(test.raster, xy = TRUE) 
 
-ggplot() +
-   geom_raster(data=test.raster_df, aes(x=x,y=y,fill=layer)) +
-   scale_fill_viridis(limits=c(0,NA),na.value="white", name="Environmental\nvalue") +
-   labs(caption = "Environmental raster") + theme_minimal() + coord_quickmap()
+if (!requireNamespace("ggplot2", quietly = TRUE) || !requireNamespace("viridis", quietly = TRUE)) {
+  message("Packages 'ggplot2' and 'viridis' are needed for plotting this figure.")
+} else {
+  library(ggplot2)
+  library(viridis)
+  
+  ggplot() +
+    geom_raster(data=test.raster_df, aes(x=x,y=y,fill=layer)) +
+    scale_fill_viridis(limits=c(0,NA),na.value="white", name="Environmental\nvalue") +
+    labs(caption = "Environmental raster") + theme_minimal() + coord_quickmap()
+}
 
-## ----RW-1, echo=FALSE, message = FALSE-----------------------------------
+## ----RW-1, echo=FALSE, message = FALSE----------------------------------------
 library(data.table)
 library(raster)
 x = seq(0,100,len=100)
@@ -98,7 +103,7 @@ for (t in 2:1001){
   move.temp= data.table(t=real.t,current.in.x=newP[1],current.in.y=newP[2])
   move.test = rbindlist(list(move.test,move.temp))
 }
-  move.test$type = "Attracted by raster"
+move.test$type = "Attracted by raster"
 
 move.test2 = data.table(t=0,current.in.x=0.25,current.in.y=0.75)
 for (t in 2:1001){
@@ -125,41 +130,44 @@ for (t in 2:1001){
       
       if (!is.na(temp.env.value)){
         move.temp= data.table(t=real.t,current.in.x=newP[1],current.in.y=newP[2])
-positionFound1 = TRUE
-positionFound2 = TRUE
+        positionFound1 = TRUE
+        positionFound2 = TRUE
       }
     }
   }
   
   
   move.test2 = rbindlist(list(move.test2,move.temp))
-
+  
 }
-   move.test2$type = "Not attracted by raster"
-   
-    move.test.all = rbindlist(list(move.test,move.test2))
-   
+move.test2$type = "Not attracted by raster"
 
-ggplot() +
-   geom_raster(data=test.raster_df, aes(x=x,y=y,fill=layer)) +
-  # geom_line(data = move.test, mapping = aes(x = current.in.x, y = current.in.y), color = "grey90") +
-  geom_point(data = move.test.all, aes(x = current.in.x, y = current.in.y,color=t)) +
-  geom_point(data=data.table(t=0,current.in.x=0.25,current.in.y=0.75), aes(x = current.in.x, y = current.in.y), color = "firebrick1",size=3) +
- theme_minimal() + facet_wrap(~type) + 
-  scale_fill_viridis(limits=c(0,NA),na.value="white", name="Environmental\nvalue") + 
-scale_color_viridis(option="magma",limits=c(0,NA),na.value="white", name="Time")
+move.test.all = rbindlist(list(move.test,move.test2))
 
-## ----setupA, eval = FALSE------------------------------------------------
+if (!requireNamespace("ggplot2", quietly = TRUE) || !requireNamespace("viridis", quietly = TRUE)) {
+  message("Packages 'ggplot2' and 'viridis' are needed for plotting this figure.")
+} else {
+  ggplot() +
+    geom_raster(data=test.raster_df, aes(x=x,y=y,fill=layer)) +
+    # geom_line(data = move.test, mapping = aes(x = current.in.x, y = current.in.y), color = "grey90") +
+    geom_point(data = move.test.all, aes(x = current.in.x, y = current.in.y,color=t)) +
+    geom_point(data=data.table(t=0,current.in.x=0.25,current.in.y=0.75), aes(x = current.in.x, y = current.in.y), color = "firebrick1",size=3) +
+    theme_minimal() + facet_wrap(~type) + 
+    scale_fill_viridis(limits=c(0,NA),na.value="white", name="Environmental\nvalue") + 
+    scale_color_viridis(option="magma",limits=c(0,NA),na.value="white", name="Time")
+}
+
+## ----setupA, eval = FALSE-----------------------------------------------------
 #  SimulationSingle <- nosoiSim(type="single", popStructure="continuous", ...)
 
-## ----setupB, eval = FALSE------------------------------------------------
+## ----setupB, eval = FALSE-----------------------------------------------------
 #  SimulationSingle <- nosoiSim(type="single", popStructure="continuous",
 #                               length.sim=300, max.infected=1000, init.individuals=1, ...)
 
-## ----setupA-dual, eval = FALSE-------------------------------------------
+## ----setupA-dual, eval = FALSE------------------------------------------------
 #  SimulationDual <- nosoiSim(type="dual", popStructure="continuous", ...)
 
-## ----pExit1, eval = FALSE------------------------------------------------
+## ----pExit1, eval = FALSE-----------------------------------------------------
 #  p_Exit_fct  <- function(t, current.env.value){
 #    if(current.env.value > 60){p=0.02}
 #    if(current.env.value < 60 && current.env.value > 30){p=0.04}
@@ -167,88 +175,99 @@ scale_color_viridis(option="magma",limits=c(0,NA),na.value="white", name="Time")
 #    return(p)
 #  }
 
-## ----pExit2, echo=FALSE, message=FALSE-----------------------------------
-library(ggplot2)
-library(dplyr)
-
-p_Exit_fctx  <- function(x){
-  if(x >= 60){p=0.02}
-  if(x < 60 && x > 30){p=0.04}
-  if(x <= 30){p=0.08}
-  return(p)
+## ----pExit2, echo=FALSE, message=FALSE----------------------------------------
+if (!requireNamespace("ggplot2", quietly = TRUE)) {
+  message("Package 'ggplot2' is needed for plotting this figure.")
+} else {
+  library(ggplot2)
+  library(dplyr)
+  
+  p_Exit_fctx  <- function(x){
+    if(x >= 60){p=0.02}
+    if(x < 60 && x > 30){p=0.04}
+    if(x <= 30){p=0.08}
+    return(p)
+  }
+  
+  data3=data.frame(v2=seq(from = 0, to = 70, by = 0.2))
+  
+  data3 = data3 %>% group_by(v2) %>% mutate(p=p_Exit_fctx(v2))
+  
+  ggplot(data=data3,aes(x=v2,y=p)) + geom_line() +  theme_minimal() + labs(x="Environmental value",y="pExit") + ylim(0,0.1)
 }
 
-data3=data.frame(v2=seq(from = 0, to = 70, by = 0.2))
-
-data3 = data3 %>% group_by(v2) %>% mutate(p=p_Exit_fctx(v2))
-
-ggplot(data=data3,aes(x=v2,y=p)) + geom_line() +  theme_minimal() + labs(x="Environmental value",y="pExit") + ylim(0,0.1)
-
-## ----pMove1, eval = FALSE------------------------------------------------
+## ----pMove1, eval = FALSE-----------------------------------------------------
 #  p_Move_fct  <- function(t){return(0.1)}
 
-## ----sdMove1, eval=FALSE-------------------------------------------------
+## ----sdMove1, eval=FALSE------------------------------------------------------
 #  sd_Move_fct  <- function(t){return(0.25)}
 
-## ----nContact1, eval = FALSE---------------------------------------------
+## ----nContact1, eval = FALSE--------------------------------------------------
 #  n_contact_fct <- function(t){abs(round(rnorm(1, 0.5, 1), 0))}
 
-## ----nContact2, echo=FALSE-----------------------------------------------
-library(ggplot2)
-library(dplyr)
-set.seed(900)
-data = data.frame(N=abs(round(rnorm(200, 0.5, 1), 0)))
+## ----nContact2, echo=FALSE----------------------------------------------------
+if (!requireNamespace("ggplot2", quietly = TRUE)) {
+  message("Package 'ggplot2' is needed for plotting this figure.")
+} else {
+  library(ggplot2)
+  library(dplyr)
+  set.seed(900)
+  data = data.frame(N=abs(round(rnorm(200, 0.5, 1), 0)))
+  
+  data = data %>% group_by(N) %>% summarise(freq=length(N)/200)
+  
+  ggplot(data=data, aes(x=as.factor(N), y=freq)) + geom_bar(stat="identity") + theme_minimal() + labs(x="nContact",y="Frequency")
+}
 
-data = data %>% group_by(N) %>% summarise(freq=length(N)/200)
-
-ggplot(data=data, aes(x=as.factor(N), y=freq)) + geom_bar(stat="identity") + theme_minimal() + labs(x="nContact",y="Frequency")
-
-
-## ----pTrans1, eval = FALSE-----------------------------------------------
+## ----pTrans1, eval = FALSE----------------------------------------------------
 #  p_Trans_fct <- function(t, p_max, t_incub){
 #      if(t < t_incub){p=0}
 #      if(t >= t_incub){p=p_max}
 #      return(p)
 #  }
 
-## ----pTrans2, eval = FALSE-----------------------------------------------
+## ----pTrans2, eval = FALSE----------------------------------------------------
 #  t_incub_fct <- function(x){rnorm(x,mean = 7,sd=1)}
 #  p_max_fct <- function(x){rbeta(x,shape1 = 5,shape2=2)}
 
-## ----pTrans3, echo=FALSE-------------------------------------------------
-library(ggplot2)
-library(dplyr)
-
-set.seed(506)
-
-p_Trans_fct <- function(t, p_max, t_incub){
+## ----pTrans3, echo=FALSE------------------------------------------------------
+if (!requireNamespace("ggplot2", quietly = TRUE)) {
+  message("Package 'ggplot2' is needed for plotting this figure.")
+} else {
+  library(ggplot2)
+  library(dplyr)
+  
+  set.seed(506)
+  
+  p_Trans_fct <- function(t, p_max, t_incub){
     if(t < t_incub){p=0}
     if(t >= t_incub){p=p_max}
     return(p)
+  }
+  
+  t_incub_fct <- function(x){rnorm(x,mean = 7,sd=1)}
+  p_max_fct <- function(x){rbeta(x,shape1 = 5,shape2=2)}
+  
+  data = data.frame(t_incub=t_incub_fct(200),p_max=p_max_fct(200),host=paste0("H-",1:200))
+  
+  t=c(0:12)
+  data3=NULL
+  for(t in 0:15){
+    data2 = data %>% group_by(host) %>% mutate(proba=p_Trans_fct(t=t,p_max=p_max, t_incub=t_incub))
+    data2$t = t
+    data3 = rbind(data3, data2)
+  }
+  
+  ggplot(data=data3, aes(x=t, y=proba,group=host)) + geom_line(color="grey60") + theme_minimal() + labs(x="Time since infection (t)",y="pTrans")
 }
 
-t_incub_fct <- function(x){rnorm(x,mean = 7,sd=1)}
-p_max_fct <- function(x){rbeta(x,shape1 = 5,shape2=2)}
-
-data = data.frame(t_incub=t_incub_fct(200),p_max=p_max_fct(200),host=paste0("H-",1:200))
-
-t=c(0:12)
-data3=NULL
-for(t in 0:15){
-  data2 = data %>% group_by(host) %>% mutate(proba=p_Trans_fct(t=t,p_max=p_max, t_incub=t_incub))
-  data2$t = t
-  data3 = rbind(data3, data2)
-}
-
-ggplot(data=data3, aes(x=t, y=proba,group=host)) + geom_line(color="grey60") + theme_minimal() + labs(x="Time since infection (t)",y="pTrans")
-
-## ----pTrans4, eval = FALSE-----------------------------------------------
+## ----pTrans4, eval = FALSE----------------------------------------------------
 #  t_incub_fct <- function(x){rnorm(x,mean = 7,sd=1)}
 #  p_max_fct <- function(x){rbeta(x,shape1 = 5,shape2=2)}
 #  
 #  param_pTrans = list(p_max=p_max_fct,t_incub=t_incub_fct)
 
-## ----setupF--------------------------------------------------------------
+## ----setupF-------------------------------------------------------------------
 library(nosoi)
 
 #Raster is test.raster
@@ -326,69 +345,81 @@ SimulationSingle <- nosoiSim(type="single", popStructure="continuous",
                              print.progress=FALSE,
                              print.step=10)
 
-## ----pExit1-dual, eval = FALSE-------------------------------------------
+## ----pExit1-dual, eval = FALSE------------------------------------------------
 #  p_Exit_fctB  <- function(t,prestime){(sin(prestime/(2*pi*10))+1)/16} #for a periodic function
 
-## ----pExit2-dual, echo = FALSE-------------------------------------------
+## ----pExit2-dual, echo = FALSE------------------------------------------------
 p_Exit_fctx <- function(x){(sin(x/(2*pi*10))+1)/16} #for a periodic function
-ggplot(data=data.frame(x=0), aes(x=x)) + stat_function(fun=p_Exit_fctx) + theme_minimal() + labs(x="Absolute time (prestime)",y="pExit") + xlim(0,360)
+if (!requireNamespace("ggplot2", quietly = TRUE)) {
+  message("Package 'ggplot2' is needed for plotting this figure.")
+} else {
+  ggplot(data=data.frame(x=0), aes(x=x)) + stat_function(fun=p_Exit_fctx) + theme_minimal() + labs(x="Absolute time (prestime)",y="pExit") + xlim(0,360)
+}
 
-## ----pMove.B, eval = FALSE-----------------------------------------------
+## ----pMove.B, eval = FALSE----------------------------------------------------
 #  p_Move_fct.B  <- NA
 
-## ----sdMove.B, eval = FALSE----------------------------------------------
+## ----sdMove.B, eval = FALSE---------------------------------------------------
 #  sd_Move_fct.B  <- NA
 
-## ----nContact1.B, eval = FALSE-------------------------------------------
+## ----nContact1.B, eval = FALSE------------------------------------------------
 #  n_contact_fct.B = function(t){sample(c(0,1,2),1,prob=c(0.6,0.3,0.1))}
 
-## ----nContact2.B, echo=FALSE---------------------------------------------
-library(ggplot2)
-library(dplyr)
-set.seed(6059)
-data = data.frame(N=sample(c(0,1,2),200,replace=TRUE,prob=c(0.6,0.3,0.1)))
+## ----nContact2.B, echo=FALSE--------------------------------------------------
+if (!requireNamespace("ggplot2", quietly = TRUE)) {
+  message("Package 'ggplot2' is needed for plotting this figure.")
+} else {
+  library(ggplot2)
+  library(dplyr)
+  set.seed(6059)
+  data = data.frame(N=sample(c(0,1,2),200,replace=TRUE,prob=c(0.6,0.3,0.1)))
+  
+  data = data %>% group_by(N) %>% summarise(freq=length(N)/200)
+  
+  ggplot(data=data, aes(x=as.factor(N), y=freq)) + geom_bar(stat="identity") + theme_minimal() + labs(x="nContact.B",y="Frequency")
+}
 
-data = data %>% group_by(N) %>% summarise(freq=length(N)/200)
-
-ggplot(data=data, aes(x=as.factor(N), y=freq)) + geom_bar(stat="identity") + theme_minimal() + labs(x="nContact.B",y="Frequency")
-
-## ----pTrans1.B, eval = FALSE---------------------------------------------
+## ----pTrans1.B, eval = FALSE--------------------------------------------------
 #  p_Trans_fct.B <- function(t, max.time){
 #    dnorm(t, mean=max.time, sd=2)*5
 #  }
 
-## ----pTrans2.B, eval = FALSE---------------------------------------------
+## ----pTrans2.B, eval = FALSE--------------------------------------------------
 #  max.time_fct <- function(x){rnorm(x,mean = 5,sd=1)}
 
-## ----pTrans3.B, echo=FALSE-----------------------------------------------
-library(ggplot2)
-library(dplyr)
-set.seed(6609)
-
-p_Trans_fct <- function(t, max.time){
-  dnorm(t, mean=max.time, sd=2)*5
+## ----pTrans3.B, echo=FALSE----------------------------------------------------
+if (!requireNamespace("ggplot2", quietly = TRUE)) {
+  message("Package 'ggplot2' is needed for plotting this figure.")
+} else {
+  library(ggplot2)
+  library(dplyr)
+  set.seed(6609)
+  
+  p_Trans_fct <- function(t, max.time){
+    dnorm(t, mean=max.time, sd=2)*5
+  }
+  
+  max.time_fct <- function(x){rnorm(x,mean = 5,sd=1)}
+  
+  data = data.frame(max.time=max.time_fct(200),host=paste0("H-",1:200))
+  
+  t=c(0:12)
+  data3=NULL
+  for(t in 0:15){
+    data2 = data %>% group_by(host) %>% mutate(proba=p_Trans_fct(t=t,max.time=max.time))
+    data2$t = t
+    data3 = rbind(data3, data2)
+  }
+  
+  ggplot(data=data3, aes(x=t, y=proba,group=host)) + geom_line(color="grey60",alpha=0.3) + theme_minimal() + labs(x="Time since infection (t)",y="pTrans")
 }
 
-max.time_fct <- function(x){rnorm(x,mean = 5,sd=1)}
-
-data = data.frame(max.time=max.time_fct(200),host=paste0("H-",1:200))
-
-t=c(0:12)
-data3=NULL
-for(t in 0:15){
-  data2 = data %>% group_by(host) %>% mutate(proba=p_Trans_fct(t=t,max.time=max.time))
-  data2$t = t
-  data3 = rbind(data3, data2)
-}
-
-ggplot(data=data3, aes(x=t, y=proba,group=host)) + geom_line(color="grey60",alpha=0.3) + theme_minimal() + labs(x="Time since infection (t)",y="pTrans")
-
-## ----pTrans4.B, eval = FALSE---------------------------------------------
+## ----pTrans4.B, eval = FALSE--------------------------------------------------
 #  max.time_fct <- function(x){rnorm(x,mean = 5,sd=1)}
 #  
 #  param_pTrans.B = list(max.time=max.time_fct)
 
-## ----setupF.B------------------------------------------------------------
+## ----setupF.B-----------------------------------------------------------------
 library(nosoi)
 
 #Raster is test.raster
